#set text(fallback: false)
#let main-color = rgb("#993300")

#let conf(
  subtitle: none,
  authors: (),
  toc: true,
  lang: "en",
  font: "PT Sans",
  date: none,
  years: (2024, 2025),
  version: none,
  title,
  doc,
) = {
  set heading(numbering: "1.1")
  show heading.where(level: 1):  it => [
    #pagebreak()
    #set par(justify:false)
    #pad(
      top: 6pt,
      text(fill: main-color, weight: "medium", size: 20pt ,smallcaps( it))
    )
  ]
  
  show heading.where(level: 2):  it => [
    #set par(justify:false)
    #pad(
      top: 6pt,
      text(fill: main-color, weight: "medium", size: 20pt ,smallcaps(it))
    )
  ]
  
  show heading.where(level: 3):  it => [
    #set par(justify:false)
    #pad(
      top: 6pt,
      text(fill: main-color, weight: "medium", size: 16pt ,smallcaps(it))
    )
  ]
  
  show heading.where(level: 4):  it => [
    #set par(justify:false)
    #pad(
      top: 6pt,
      text(fill: main-color, weight: "medium", size: 14pt ,smallcaps(it))
    )
  ]
  
  show outline.entry.where(
    level: 1
  ): it => {
    v(12pt, weak: true)
    text(fill: main-color, weight: "medium", size: 20pt ,smallcaps(it))
  }

  
  
  set text(lang: lang, font: font, fallback: false)
  set par(
	  justify: true,
	  leading: 1em,
	  spacing: 1.5em
  )
  show heading: set block(below: 2em)
  
  set list(spacing: 2em, indent: 2em, body-indent: 0.5em,marker: box(height: 0.65em, align(horizon+center, text(fill: main-color, size: 3em)[•])))

  
  v(32pt)
  align(center)[#image("assets/i2MassChroQ_icon.svg", width: 50%)]
  
  v(32pt)
  let count = authors.len()
  let ncols = 1
  if count > 3 {
      ncols = 2
  }
  v(32pt)

  align(center)[
    #line(length: 100%)
    #v(16pt)
    #text(size: 32pt, weight: "medium", fill: main-color)[#smallcaps(title)]\
    #v(16pt)
    #if (subtitle != none) {
      line(length: 10%)
      text(size: 18pt, weight: "medium", fill: main-color)[#smallcaps(subtitle)]
    }
    #line(length: 100%)
    #v(64pt)
    #text(20pt, str("version: ") + version)

    #align(bottom)[
      #grid(
        columns: (0.5fr,) * ncols,
        row-gutter: 12pt,
        ..authors.map(author => [
          #text(16pt, author.name) \
        ]
        ),
      )]
  ]

  pagebreak()
  set align(left)
  

  show link: it => {
    set text(rgb("#993300"))
    it
    box(image("assets/external-link-svgrepo-com.svg"),height:0.6em)
  }

  if toc {
    set outline.entry(fill: none)
    outline(indent: 2em, depth: 2)
    outline(
      title: [List of Figures],
      target: figure,
    )
  }
  set page(
    margin: (top: 42pt),
    header: [
      #set text(8pt)
      #smallcaps[#title]
      #if (date != none) {
        h(1fr) + text(date)
      }
      #line(length: 100%)
    ],
  )
  doc
}

#let c = counter("question")
#let question(title, counter: true) = context {
  v(8pt)
  if (counter) {
    c.step()
    heading(level: 2, c.display() + ") " + title)
  } else {
    heading(level: 2, title)
  }  
  v(4pt)
}

#let code-block(code, language, title: none) = {
  v(6pt)

  if (title != none) {
    text(10pt, style: "italic", title) 
    linebreak()
  }
  raw(code, lang: language)
  v(6pt)
}

#let remarque(content, bg-color: silver, text-color: black) = {
  v(4pt)
  block(
    fill: bg-color,
    width: 100%,
    inset: 8pt,
    radius: 4pt,
    text(10pt, content, fill: text-color)
  )
}


#let application(content) = {
  text(content, style: "italic")
}

#let productname(content) = {
  text(content, style: "italic")
}

#let command(content) = {
  text(underline(content), style: "normal", stroke: 0.5pt)
}

#let filename(content) = {
  text(content, style: "normal", font: "Liberation Mono")
}

#let mcq = emph("MassChroQ")
#let mcqr = emph("MCQR")
#let i2mcq = emph("i2MassChroQ")
#let xtandem = emph("X!Tandem")
#let xtpjava = emph("X!TandemPipeline-Java")
#let xtpcpp = emph("X!TandemPipeline++")
#let nbsp = sym.space.nobreak
#let massXp = emph("massXpert")


#let block-tip(body) = block(width: 100%, {
    stack(dir: ltr, spacing: 0.2em,{
        box(width: 10%, image("assets/idea-lamp-svgrepo-com.svg"))
    },{box(width: 90%,{
        set align(left)
        block(text(fill: main-color, weight: "medium", size: 20pt)[#smallcaps("Tip")])
        set text(size: 1em)
        body})
    }
    )
}
)

#let block-note(body) = block(width: 100%, {
    stack(dir: ltr, spacing: 0.2em,{
        box(width: 10%, image("assets/clip-data-document-file-page-paper-svgrepo-com.svg"))
    },{box(width: 90%,{
        set align(left)
        block(text(fill: main-color, weight: "medium", size: 20pt)[#smallcaps("Note")])
        set text(size: 1em)
        body})
    }
    )
}
)



#let code-prompt(code,  title: none) = {
  
show raw.line: it => block(
  text( "$ " + it.body+" " + box(rect(inset: 3pt, height: 1em,radius: 5pt, fill: rgb("#a2aabc"))[#text(size: 0.5em,"RETURN")]))
)
  v(6pt)

  if (title != none) {
    text(10pt, style: "italic", title) 
    linebreak()
  }
  raw(code, lang: "bash")
  v(6pt)
}
