#import "../template.typ": *
#import "@preview/typsium:0.2.0": ce


= Fundamentals in Bottom-up Proteomics

This chapter is an optional chapter which the reader might be referred to upon
  reading other part of this manual.

  

== The Protein Biopolymer: Structure and Chemistry <sect_protein-biopolymer-structure-chemistry>

This section introduces the basics in protein polymer chemistry. The way
    this topic is going to be covered is admittedly biased towards mass
    spectrometry and proteins. Moreover, the aim of this chapter is to provide
    the reader with the specialized words that will later be used to describe
    and explain the (inner) workings of the &i2mcq; program. This manual is not
    a #quote[crash course] in biochemistry.


=== Protein Biosynthesis <sect_protein-biosynthesis>

Proteins are made of amino acids. There are twenty major amino acids in
      nature, and each protein is made of a number of these amino acids. The
      combinations are infinite, providing enormous diversity to the protein realm.
      
      
A protein is a polar polymer: it has a left end and a right end, and polymerization actually occurs from left to right (from N-terminus to C-terminus, see below). @fig_xtpcpp-peptide-bond-formation shows that the chemical reaction at the basis of protein synthesis is a #emph[condensation].
A protein is the result of the condensation of amino acids with each other in an orderly polar fashion.
A protein has a left end, called #emph[N-terminus; amino-terminal end] and a right end, called #emph[C-terminus; carboxy-terminal end]. The left end is an amino group (#ce("H2N-")) corresponding to the non-reacted #sym.alpha;-amino group of the very first amino acid of the protein sequence.
Upon condensation of a new entering amino acid onto the first N-terminal one, the amino group of the entering amino acid reacts (nucleophilic attack) with the #sym.alpha;-carboxyl group of the N-terminal amino acid.
A water molecule is released, and the formation of an amide bond between the two amino acids yields a dipeptide.
The right end of the dipeptide is a carboxyl group (#ce("COOH")) corresponding to the un-reacted #sym.alpha;-carboxyl group of the last amino acid to have been #quote[polymerized in].


The bond formed by condensation of two amino acids is an amide bond, also called#sym.dash.em;in protein chemistry#sym.dash.em;a #emph[peptidic bond].
The elongation of the protein is a simple repetition of the condensation reaction shown in @fig_xtpcpp-peptide-bond-formation, granted that the elongation #emph[always] proceeds in the described direction (a new monomer arrives to the right end of the elongating polymer, and elongation is done from left to right).

#include "a3a1_figure_peptide_bond.typ"

#block-note[
Now we should point at a protein chemistry-specific terminology issue: we
      have seen that a protein is a polymer made of a number of monomers, called
      #emph[amino acids]. In protein chemistry, there is a
      subtlety: once an amino acid has been polymerized into a protein, it is no
      more called an amino acid, but is called a #emph[residue]
      instead.  We may say that a residue is an amino acid less a water
      molecule. ]

From what we have seen until now, we may define a protein this way:
    #sym.dash.em;#emph[#quote[A protein is a chain of residues linked together in an orderly polar fashion,
    with the residues being numbered starting from 1 and ending at n, from the
    first residue on the left end to the last one on the right
    end]]. This definition is still partly inexact, however.
    Indeed, from what is shown in @fig_xtpcpp-protein-polymer,
    there is still a problem with the extremities of the residual chain: what
    about the amino group on the left end of a protein (the amino group sits
    right onto the first amino acid of the protein), and what about the carboxyl
    group of the right end of a protein (the carboxyl group sits right onto the
    last amino acid of the protein)? Because these groups lie at the extremities
    of the residual chain, they remained unreacted during the polymerization
    process. But because we are simulating a residual chain using residues and
    not amino-acids, we still need to put the protein polymer molecule in its
    #quote[finished state]: by #emph[capping] the left end
    with a proton #emph[cap] (so as to complete the amino group)
    and the right end with a hydroxyl cap (so as to complete the carboxyl
    group). The capping of the residual chain extremities ensures that the
    polymer is in its finished state, and that it cannot be elongated anymore.
    The proton is the #emph[left cap] of the protein polymer and
    the hydroxyl is the #emph[right cap] of the protein polymer.


#include "a3a2_figure_protein_polymer.typ"



Now comes the question of unambiguously defining the structure of a protein.
    It is commonly accepted that the simple ordered sequence of each residue
    code in the protein, from left to right, constitutes an unambiguous
    description of the protein's primary structure (that is, its sequence). Of
    course, proteins have three-dimensional structures, but this is of no
    interest to a program like #massXp;#cite(<rusconi_massxpert_2009>), which is aimed at calculating masses of
    polymers. To enunciate unambiguously the sequence of a protein, one would
    use a symbology like this: 

- Using the 3-letter code of the amino acids: \
  Ala Gly Trp Tyr Glu Gly Lys
- Using the 1-letter code of the amino acids:\
  A G W Y E G K\
  Alanine is thus the residue 1 and Lysine is the last residue (n = 7)



=== Protein Disrupting Chemistries

The #quote[polymer chain disrupting chemistry] was mentioned earlier
    as a complex subject that was of #emph[enormous] importance to
    the mass spectrometrist. This is why that subject will be treated in a
    pretty thorough manner. First of all it should be noted that a chemical
    modification of a polymer does not necessarily involve the perturbation of
    the chain structure of the polymer.  Here, however, we are concerned
    specifically with a number of chemical modifications that yield a polymer
    chain perturbation; #emph[cleavages] and
    #emph[fragmentations]:
    
/ Cleavages: These are chemical processes by which a cleaving agent will act directly
      on the protein residual chain making it fall into at least two separated
      pieces (the peptides).
      
/ Fragmentations: These are chemical processes by which the polymer structure is disrupted into separated pieces (the #emph[product ions], or #emph[fragments]) mainly because of energy-dependent electron doublet rearrangements leading to bond breakage.



==== Protein Cleavage<sect_protein-cleavage>

Upon cleavage of a protein, the cleaving molecule reacts with it, and by
      doing so directly or indirectly
      #emph[#quote[dissolves]] an inter-residue bond. A
      protein cleavage always occurs in such a way as to generate a set of
      #emph[true] finished polymerization state
      #quote[proteins] (smaller in size than the parent polymer,
      evidently, which is why they are called
      #emph[oligopeptides], or #emph[peptides]).
      Indeed, let us take the example shown in @fig_xtpcpp-protein-cleavage, where a tripeptide (a very little protein,
      containing a methionyl residue at position 2) is submitted either to a
      water-mediated cleavage (hydrolysis, upper panel) or to a cyanogen
      bromide-mediated cleavage (lower panel). The two cases presented in this
      figure are similar in some respects and different in others:

#figure([], caption: "Protein Cleavage by Water and Cyanogen Bromide"
) <fig_xtpcpp-protein-cleavage>
